"use strict";

const {
  cloneViaCdt
} = require("../utils/CloneCommonLinterRepo/cloneViaCdt");
const {
  setupHusky
} = require("../utils/HuskySetup/setupHusky");
const {
  createEslintConfigFile
} = require("../utils/EslintConfigFileUtils/createEslintConfigFile");
const {
  Logger
} = require("../utils/Logger/Logger");
const {
  executeMethodsThatReturnBooleanValue
} = require("../utils/General/wrapperFunctionToExecuteAFunction");
const {
  arePluginsInstalled
} = require("../utils/PluginsInstallation/arePluginsInstalled");
const {
  isGitInitialized
} = require("../utils/GitActions/gitActions");
const {
  writeFsPaths
} = require("../utils/General/writeProjectDetailsToJson");

/**
 *  @function {postInstall} -  This methods setup husky and configuration for executing project
 *  @returns {void}
 */
async function postInstall() {
  try {
    await executeMethodsThatReturnBooleanValue("Some issue in writing node_modules path to json", writeFsPaths, null);
    isGitInitialized() ? await executeMethodsThatReturnBooleanValue("Some issue occurred in setting up husky.", setupHusky, null) : null;
    await executeMethodsThatReturnBooleanValue("Make sure zgit.csez.zohocorpin.com is accessible", cloneViaCdt, null);
    await executeMethodsThatReturnBooleanValue("Some issue occurred in creating eslint config file.", createEslintConfigFile, null);
    Logger.log(Logger.SUCCESS_TYPE, "Pre commit setup successful");
    arePluginsInstalled();
  } catch (error) {
    Logger.log(Logger.FAILURE_TYPE, `Kindly retry npm install. & ${error.message}`);
  }
}
postInstall();