"use strict";

const {
  execSync
} = require("child_process");
const {
  getClonedDirPath,
  getDeleteDirPath
} = require('./HelperFunctions/helpers');
const {
  getRepoName
} = require("../GitActions/gitActions");
const {
  removeFolder
} = require("../FileAndFolderOperations/removeFolder");
const {
  executeSynchronizedCommands
} = require('../General/executeSyncCommands');
const {
  Logger
} = require('../Logger/Logger');
const cloneRepoProperties = {
  endPoint: "https://rajasekar.hm:JzPFGpj2fayCG1cJGKUz@zgit.csez.zohocorpin.com/code_standard/client_linter/linter_configuration.git",
  branch: "master",
  cacheDirectory: "./",
  name: "configuration",
  type: "git"
};
/**
 * @function cloneViaCdt - Using the "clint development tool" clones the common linter_configuration repo into precommit library
 * @returns {boolean} - indicating the success or failure of the cloning process
 */

function cloneViaCdt() {
  removeFolder(getDeleteDirPath());
  const commandToCloneCommonConfigRepo = `npx cdt clone --clone:type=${cloneRepoProperties.type} --clone:url=${cloneRepoProperties.endPoint} --clone:branch=${cloneRepoProperties.branch} --clone:cacheDir=${cloneRepoProperties.cacheDirectory} --clone:proj:name=${cloneRepoProperties.name}`;
  let isCommonConfigurationClonedSuccessfully = executeSynchronizedCommands(execSync, [commandToCloneCommonConfigRepo, {
    cwd: getClonedDirPath()
  }], `Lint Configuration Cloned Successfully - ${getRepoName() || 'common'}`, 'Could not clone the linters common repo', false, true);
  return isCommonConfigurationClonedSuccessfully;
}
module.exports = {
  cloneViaCdt
};