"use strict";

const path = require('path');
const {
  writeFileSync,
  existsSync,
  unlinkSync,
  readFileSync
} = require('fs');
const {
  getNodeModulesPath
} = require('../General/getNodeModulesPath.js');
const {
  Logger
} = require('../Logger/Logger.js');
const {
  executeSynchronizedCommands
} = require('../General/executeSyncCommands.js');
const {
  getServicePathElseCommon
} = require('./getLintConfiguration.js');
let eslintConfiguration = ``;

/**
 * @function createEslintConfigFile - creates a eslint configuration file based on the configuration file in the common linters repo
 * @returns {boolean} - indicating the success or failure in creating the eslint configuration file
 */
function createEslintConfigFile() {
  const eslintConfigFilePath = path.join(getNodeModulesPath(), '.eslintrc.js');
  const {
    pathOfServiceSpecificEslintConfigFile
  } = getServicePathElseCommon();
  eslintConfiguration = executeSynchronizedCommands(readFileSync, [pathOfServiceSpecificEslintConfigFile, 'utf-8'], '', 'Unable to read content of eslint config file.', true, false);
  try {
    let isEslintConfigFilePresent = existsSync(eslintConfigFilePath);
    if (isEslintConfigFilePresent) {
      executeSynchronizedCommands(unlinkSync, [eslintConfigFilePath], 'Eslint configuration file removed successfully!', 'Unable to remove the eslint config file.', false, false);
      return createEslintConfigurationFile();
    } else if (!isEslintConfigFilePresent) {
      return createEslintConfigurationFile();
    }
  } catch (error) {
    Logger.log(Logger.FAILURE_TYPE, error);
    Logger.log(Logger.FAILURE_TYPE, 'Issue occured while checking if eslint config file exists');
  }
}
function createEslintConfigurationFile() {
  const eslintConfigFilePath = path.join(getNodeModulesPath(), '.eslintrc.js');
  let isEslintConfigFileCreated = executeSynchronizedCommands(writeFileSync, [eslintConfigFilePath, eslintConfiguration, 'utf-8'], 'Eslint configuration file created successfully!', 'Unable to create and write an eslint configuration file.', false, true);
  return isEslintConfigFileCreated;
}
module.exports = {
  createEslintConfigFile
};