"use strict";

const path = require('path');
const {
  existsSync
} = require('fs');
const {
  repoURL
} = require("../../../jsonUtils/commonLinterRepoDetails.js");
const {
  getRepoName
} = require('../GitActions/gitActions');
const {
  getLibraryInstalledLocation
} = require('../General/getLibraryInstalledLocation');
const {
  executeMethodsThatMayThrowException
} = require("../General/wrapperFunctionToExecuteAFunction");

/**
 * @function getLintConfiguration - returns eslint configuration file from common linters repo
 * @returns {object} - containing properties of the eslint configuration file
 */
function getServicePathElseCommon() {
  const repoName = getRepoName();
  const libraryInstalledLocation = getLibraryInstalledLocation();
  let commonConfigPath = path.join(libraryInstalledLocation, 'configuration', 'common', 'index.js');
  const _configurationPath = repoName && existsSync(path.join(libraryInstalledLocation, 'configuration', 'services', repoName, 'index.js')) ? path.join(libraryInstalledLocation, 'configuration', 'services', repoName, 'index.js') : commonConfigPath;
  let _pathOfServiceSpecificEslintConfigFile = repoName && existsSync(path.join(libraryInstalledLocation, 'configuration', 'services', repoName, '.eslintrc.js')) ? path.join(libraryInstalledLocation, 'configuration', 'services', repoName, '.eslintrc.js') : path.join(libraryInstalledLocation, 'configuration', 'common', '.eslintrc.js');
  let _pluginVersionPath = repoName && existsSync(path.join(libraryInstalledLocation, 'configuration', 'services', repoName, 'pluginVersion.js')) ? path.join(libraryInstalledLocation, 'configuration', 'services', repoName, 'pluginVersion.js') : undefined;
  return {
    configurationPath: _configurationPath,
    pathOfServiceSpecificEslintConfigFile: _pathOfServiceSpecificEslintConfigFile,
    pluginVersionPath: _pluginVersionPath
  };
}
function getLintConfigurationUtil() {
  const {
    configurationPath
  } = getServicePathElseCommon();
  const exceptionHandleObject = {
    rulesConfig: [{}, {}],
    plugins: [],
    extendPlugins: []
  };
  return executeMethodsThatMayThrowException(exceptionHandleObject, `Kindly Ensure that Configuration is setup in Configuration repo \n ${repoURL}`, require, configurationPath);
}
module.exports = {
  getLintConfigurationUtil,
  getServicePathElseCommon
};