"use strict";

const {
  existsSync,
  rmSync
} = require('fs');
const {
  Logger
} = require('../Logger/Logger');
const {
  executeSynchronizedCommands
} = require('../General/executeSyncCommands');

/**
 * @function removeFolder - removes the given folder if it exists
 * @param {string} folderPath - path to folder that must be removed
 * @returns {void}
 */
function removeFolder(folderPath) {
  try {
    let isCommonConfigFolderPresent = existsSync(folderPath);
    if (isCommonConfigFolderPresent) {
      executeSynchronizedCommands(rmSync, [folderPath, {
        recursive: true,
        force: true
      }], 'common linter configuration folder removed successfully', 'Unable to remove the common linter configuration folder', false, false);
    } else {
      Logger.log(Logger.SUCCESS_TYPE, 'Configuration folder not present');
    }
  } catch (error) {
    Logger.log(Logger.FAILURE_TYPE, error);
    Logger.log(Logger.FAILURE_TYPE, 'Unable to check if common linter configuration folder is present');
  }
}
module.exports = {
  removeFolder
};