"use strict";

const {
  writeFileSync
} = require("fs");
const path = require("path");
const grantExecutionPermission = require("../FileAndFolderOperations/grantExecutionPermission");
const {
  getRootDirectory
} = require("../General/RootDirectoryUtils/getRootDirectory");
const {
  getLibraryInstalledLocation
} = require("../General/getLibraryInstalledLocation");
const {
  executeSynchronizedCommands
} = require("../General/executeSyncCommands");

/**
 * @function configurePrecommitHook - creates the link to custom pre commit hook file and husky precommit file 
 * @returns {boolean} - indicates if custom precommit hook created successfully or not
 */
function configurePrecommitHook() {
  let rootDirectory = getRootDirectory();
  let customPrecomitHookPath = path.join(getLibraryInstalledLocation(), "bin", "execute.js");
  let huskyPrecommitPath = path.join(rootDirectory, ".husky", "pre-commit");
  let huskyPrecommitHookContent = `#!/bin/sh
. "$(dirname "$0")/_/husky.sh"

"${customPrecomitHookPath}"
`;
  let isCustomPrecommitConfigurationSuccessful = executeSynchronizedCommands(writeFileSync, [huskyPrecommitPath, huskyPrecommitHookContent, 'utf-8'], '', 'Could not create and write pre-commit.sh inisde husky directory', false, true);
  if (isCustomPrecommitConfigurationSuccessful) {
    let isExecutionPermissionGivenSuccessfully = grantExecutionPermission([huskyPrecommitPath, customPrecomitHookPath]);
    return isExecutionPermissionGivenSuccessfully;
  } else {
    return false;
  }
}
module.exports = configurePrecommitHook;